@@ -210,10 +210,9 @@ class Ui_DialogOptions(object):
         self.labelLibDirs = QtWidgets.QLabel(self.groupBoxNativeOptions)
         self.labelLibDirs.setObjectName("labelLibDirs")
         self.gridLayout_5.addWidget(self.labelLibDirs, 2, 0, 1, 1)
-        self.labelRebuildNativeStatus = QtWidgets.QLabel(self.groupBoxNativeOptions)
-        self.labelRebuildNativeStatus.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
-        self.labelRebuildNativeStatus.setObjectName("labelRebuildNativeStatus")
-        self.gridLayout_5.addWidget(self.labelRebuildNativeStatus, 4, 2, 1, 1)
+        self.lineEditIncludeDirs = QtWidgets.QLineEdit(self.groupBoxNativeOptions)
+        self.lineEditIncludeDirs.setObjectName("lineEditIncludeDirs")
+        self.gridLayout_5.addWidget(self.lineEditIncludeDirs, 3, 2, 1, 1)
         self.labelNativeRebuildInfo = QtWidgets.QLabel(self.groupBoxNativeOptions)
         self.labelNativeRebuildInfo.setWordWrap(True)
         self.labelNativeRebuildInfo.setObjectName("labelNativeRebuildInfo")
@@ -221,6 +220,9 @@ class Ui_DialogOptions(object):
         self.lineEditLibDirs = QtWidgets.QLineEdit(self.groupBoxNativeOptions)
         self.lineEditLibDirs.setObjectName("lineEditLibDirs")
         self.gridLayout_5.addWidget(self.lineEditLibDirs, 2, 2, 1, 1)
+        self.labelIncludeDirs = QtWidgets.QLabel(self.groupBoxNativeOptions)
+        self.labelIncludeDirs.setObjectName("labelIncludeDirs")
+        self.gridLayout_5.addWidget(self.labelIncludeDirs, 3, 0, 1, 1)
         self.btnViewBuildLog = QtWidgets.QPushButton(self.groupBoxNativeOptions)
         icon = QtGui.QIcon.fromTheme("utilities-log-viewer")
         self.btnViewBuildLog.setIcon(icon)
@@ -232,12 +234,10 @@ class Ui_DialogOptions(object):
         self.btnRebuildNative.setIcon(icon)
         self.btnRebuildNative.setObjectName("btnRebuildNative")
         self.gridLayout_5.addWidget(self.btnRebuildNative, 4, 0, 1, 1)
-        self.labelIncludeDirs = QtWidgets.QLabel(self.groupBoxNativeOptions)
-        self.labelIncludeDirs.setObjectName("labelIncludeDirs")
-        self.gridLayout_5.addWidget(self.labelIncludeDirs, 3, 0, 1, 1)
-        self.lineEditIncludeDirs = QtWidgets.QLineEdit(self.groupBoxNativeOptions)
-        self.lineEditIncludeDirs.setObjectName("lineEditIncludeDirs")
-        self.gridLayout_5.addWidget(self.lineEditIncludeDirs, 3, 2, 1, 1)
+        self.labelRebuildNativeStatus = QtWidgets.QLabel(self.groupBoxNativeOptions)
+        self.labelRebuildNativeStatus.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
+        self.labelRebuildNativeStatus.setObjectName("labelRebuildNativeStatus")
+        self.gridLayout_5.addWidget(self.labelRebuildNativeStatus, 4, 2, 1, 1)
         self.verticalLayout_8.addWidget(self.groupBoxNativeOptions)
         self.line_2 = QtWidgets.QFrame(self.tabDevices)
         self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
@@ -248,36 +248,15 @@ class Ui_DialogOptions(object):
         self.groupBox_3.setObjectName("groupBox_3")
         self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_3)
         self.gridLayout_2.setObjectName("gridLayout_2")
-        self.label_11 = QtWidgets.QLabel(self.groupBox_3)
-        font = QtGui.QFont()
-        font.setItalic(True)
-        self.label_11.setFont(font)
-        self.label_11.setObjectName("label_11")
-        self.gridLayout_2.addWidget(self.label_11, 0, 0, 1, 2)
-        self.lineEditPython2Interpreter = QtWidgets.QLineEdit(self.groupBox_3)
-        self.lineEditPython2Interpreter.setObjectName("lineEditPython2Interpreter")
-        self.gridLayout_2.addWidget(self.lineEditPython2Interpreter, 1, 1, 1, 1)
-        self.lGnuradioInstalled = QtWidgets.QLabel(self.groupBox_3)
-        self.lGnuradioInstalled.setStyleSheet("")
-        self.lGnuradioInstalled.setObjectName("lGnuradioInstalled")
-        self.gridLayout_2.addWidget(self.lGnuradioInstalled, 3, 0, 1, 2)
-        self.lineEditGnuradioDirectory = QtWidgets.QLineEdit(self.groupBox_3)
-        self.lineEditGnuradioDirectory.setEnabled(True)
-        self.lineEditGnuradioDirectory.setText("")
-        self.lineEditGnuradioDirectory.setObjectName("lineEditGnuradioDirectory")
-        self.gridLayout_2.addWidget(self.lineEditGnuradioDirectory, 2, 1, 1, 1)
-        self.radioButtonPython2Interpreter = QtWidgets.QRadioButton(self.groupBox_3)
-        self.radioButtonPython2Interpreter.setObjectName("radioButtonPython2Interpreter")
-        self.gridLayout_2.addWidget(self.radioButtonPython2Interpreter, 1, 0, 1, 1)
-        self.radioButtonGnuradioDirectory = QtWidgets.QRadioButton(self.groupBox_3)
-        self.radioButtonGnuradioDirectory.setObjectName("radioButtonGnuradioDirectory")
-        self.gridLayout_2.addWidget(self.radioButtonGnuradioDirectory, 2, 0, 1, 1)
-        self.btnChoosePython2Interpreter = QtWidgets.QToolButton(self.groupBox_3)
-        self.btnChoosePython2Interpreter.setObjectName("btnChoosePython2Interpreter")
-        self.gridLayout_2.addWidget(self.btnChoosePython2Interpreter, 1, 2, 1, 1)
-        self.btnChooseGnuRadioDirectory = QtWidgets.QToolButton(self.groupBox_3)
-        self.btnChooseGnuRadioDirectory.setObjectName("btnChooseGnuRadioDirectory")
-        self.gridLayout_2.addWidget(self.btnChooseGnuRadioDirectory, 2, 2, 1, 1)
+        self.label = QtWidgets.QLabel(self.groupBox_3)
+        self.label.setObjectName("label")
+        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
+        self.lineEditGRPythonInterpreter = QtWidgets.QLineEdit(self.groupBox_3)
+        self.lineEditGRPythonInterpreter.setObjectName("lineEditGRPythonInterpreter")
+        self.gridLayout_2.addWidget(self.lineEditGRPythonInterpreter, 0, 1, 1, 1)
+        self.btnChooseGRPythonInterpreter = QtWidgets.QToolButton(self.groupBox_3)
+        self.btnChooseGRPythonInterpreter.setObjectName("btnChooseGRPythonInterpreter")
+        self.gridLayout_2.addWidget(self.btnChooseGRPythonInterpreter, 0, 2, 1, 1)
         self.verticalLayout_8.addWidget(self.groupBox_3)
         self.line_3 = QtWidgets.QFrame(self.tabDevices)
         self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
@@ -350,27 +329,20 @@ class Ui_DialogOptions(object):
         self.labelDeviceMissingInfo.setText(_translate("DialogOptions", "<html><head/><body><p>Missing a native backend? Perform a <a href=\"health_check\"><span style=\" text-decoration: underline; color:#0000ff;\">health check</span></a>! If GNU Radio backend is not available double check the GNU Radio settings below.</p></body></html>"))
         self.groupBoxNativeOptions.setTitle(_translate("DialogOptions", "Native options"))
         self.labelLibDirs.setText(_translate("DialogOptions", "Library directories:"))
-        self.labelRebuildNativeStatus.setText(_translate("DialogOptions", "Rebuild <x> new device extensions. Please restart URH to use them."))
+        self.lineEditIncludeDirs.setPlaceholderText(_translate("DialogOptions", "Comma separated list of additional include directories"))
         self.labelNativeRebuildInfo.setText(_translate("DialogOptions", "You can rebuild the native device extensions here. This is useful, when you installed a device driver afterwards or your drivers are stored in an unusual location."))
         self.lineEditLibDirs.setPlaceholderText(_translate("DialogOptions", "Comma separated list of additional library directories"))
+        self.labelIncludeDirs.setText(_translate("DialogOptions", "Include directories:"))
         self.btnViewBuildLog.setText(_translate("DialogOptions", "View log"))
         self.btnRebuildNative.setToolTip(_translate("DialogOptions", "<html><head/><body><p>Rebuild the native device extensions. You need to restart URH after this, to use new extensions.</p></body></html>"))
         self.btnRebuildNative.setText(_translate("DialogOptions", "Rebuild"))
-        self.labelIncludeDirs.setText(_translate("DialogOptions", "Include directories:"))
-        self.lineEditIncludeDirs.setPlaceholderText(_translate("DialogOptions", "Comma separated list of additional include directories"))
-        self.groupBox_3.setTitle(_translate("DialogOptions", "GNU Radio options"))
-        self.label_11.setText(_translate("DialogOptions", "Needed for GNU Radio backend only"))
-        self.lineEditPython2Interpreter.setToolTip(_translate("DialogOptions", "<html><head/><body><p>Use this option if you installed GNU Radio with your package manager e.g. on Linux and Mac OS X.</p></body></html>"))
-        self.lineEditPython2Interpreter.setPlaceholderText(_translate("DialogOptions", "/usr/bin/python2"))
-        self.lGnuradioInstalled.setText(_translate("DialogOptions", "GNU Radio installation found"))
-        self.lineEditGnuradioDirectory.setToolTip(_translate("DialogOptions", "<html><head/><body><p>If you installed Gnuradio with a bundled python interpreter, you need to enter the site-packages path of the installation here. The path should be something like <span style=\" font-style:italic;\">C:\\Program Files\\GNURadio-3.7</span>.</p></body></html>"))
-        self.lineEditGnuradioDirectory.setPlaceholderText(_translate("DialogOptions", "C:\\Program Files\\GNURadio"))
-        self.radioButtonPython2Interpreter.setToolTip(_translate("DialogOptions", "<html><head/><body><p>Use this option if you installed GNU Radio with your package manager e.g. on Linux and Mac OS X.</p></body></html>"))
-        self.radioButtonPython2Interpreter.setText(_translate("DialogOptions", "&Python2 interpreter"))
-        self.radioButtonGnuradioDirectory.setToolTip(_translate("DialogOptions", "<html><head/><body><p>If you installed Gnuradio with a bundled python interpreter, you need to enter the site-packages path of the installation here. The path should be something like <span style=\" font-style:italic;\">C:\\Program Files\\GNURadio-3.7</span>.</p></body></html>"))
-        self.radioButtonGnuradioDirectory.setText(_translate("DialogOptions", "GNU Radio Directory"))
-        self.btnChoosePython2Interpreter.setText(_translate("DialogOptions", "..."))
-        self.btnChooseGnuRadioDirectory.setText(_translate("DialogOptions", "..."))
+        self.labelRebuildNativeStatus.setText(_translate("DialogOptions", "Rebuild <x> new device extensions. Please restart URH to use them."))
+        self.groupBox_3.setTitle(_translate("DialogOptions", "GNU Radio options (optional)"))
+        self.label.setToolTip(_translate("DialogOptions", "<html><head/><body><p>Choose a python interpreter which has access to your GNU Radio installation, that is, you can do <span style=\" font-weight:600;\">python -c &quot;import gnuradio&quot;</span> with it on the command line.</p></body></html>"))
+        self.label.setText(_translate("DialogOptions", "Python Interpreter:"))
+        self.lineEditGRPythonInterpreter.setToolTip(_translate("DialogOptions", "<html><head/><body><p>Choose a python interpreter which has access to your GNU Radio installation, that is, you can do <span style=\" font-weight:600;\">python -c &quot;import gnuradio&quot;</span> with it on the command line.</p></body></html>"))
+        self.lineEditGRPythonInterpreter.setPlaceholderText(_translate("DialogOptions", "Enter python interpreter path e.g. /usr/bin/python"))
+        self.btnChooseGRPythonInterpreter.setText(_translate("DialogOptions", "..."))
         self.label_8.setText(_translate("DialogOptions", "Default sending repititions:"))
         self.spinBoxNumSendingRepeats.setSpecialValueText(_translate("DialogOptions", "Infinite"))
         self.label_5.setText(_translate("DialogOptions", "Use this percentage of available RAM for buffer allocation:"))
